==> digikam-4.2.0.tar.bz2: digikam-4.2.0/extra/kipi-plugins/expoblending/plugin/kipiplugin_expoblending.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Expo Blending
Name=Expo Blending
Name[bg]=Сливане на експозиция
Name[bs]=ExpoBlending
Name[ca]=Fusió d'exposició
Name[ca@valencia]=Fusió d'exposició
Name[cs]=Smísení expozice
Name[da]=Ekspo.-blanding
Name[de]=Belichtungsvermischung
Name[el]=Ανάμειξη έκθεσης
Name[en_GB]=Expo Blending
Name[es]=Mezcla de la exposición
Name[et]=Pildiliitmine
Name[eu]=Esposizioaren nahasketa
Name[fr]=Fusion d'exposition
Name[gl]=Mistura da exposición
Name[is]=Lýsingarblöndun
Name[it]=Doppia esposizione
Name[km]=ការ​លាយ​កម្រិត​បង្ហាញ
Name[lv]=Expo Blending
Name[nb]=Ekspo-fletting
Name[nl]=Belichting mengen
Name[pl]=Przenikanie naświetleń
Name[pt]=Mistura da Exposição
Name[pt_BR]=Mistura da exposição
Name[ro]=Fuziune expunere
Name[ru]=Смешивание экспозиции
Name[sk]=Expo Blending
Name[sl]=Expo Blending
Name[sv]=Exponeringsblandning
Name[tr]=Expo Blending
Name[uk]=Злиття експозиції
Name[x-test]=xxExpo Blendingxx
Name[zh_CN]=曝光混合
Name[zh_TW]=曝光混合
Comment=A tool to blend bracketed images
Comment[bg]=Инструмент за сливане на снимани "в клин" снимки
Comment[bs]=Alat za miješanje kockastih slika
Comment[ca]=Una eina per fusionar imatges fetes amb bràqueting
Comment[ca@valencia]=Una eina per fusionar imatges fetes amb bràqueting
Comment[cs]=Nástroj pro mísení sekvence obrázků
Comment[da]=Et værktøj til at blande billeder med bracket
Comment[de]=Ein Werkzeug, um Bilder aus einer Belichtungsreihe zu mischen
Comment[el]=Εργαλείο ανάμειξης οριοθετημένων εικόνων
Comment[en_GB]=A tool to blend bracketed images
Comment[es]=Una herramienta para mostrar imágenes delimitadas
Comment[et]=Tööriist kahveldatud piltide liitmiseks
Comment[eu]=Urkilatutako irudiak nahasteko tresna
Comment[fr]=Outil pour fusionner des images prises avec différentes expositions
Comment[gl]=Unha ferramenta para mesturar as imaxes tomadas en "bracketing"
Comment[is]=Verkfæri til að setja saman mislýstar myndraðir (bracketed)
Comment[it]=Uno strumento per fondere immagini sovrapposte
Comment[km]=ឧបករណ៍​ត្រូវ​លៃតម្រូវ​កាលបរិច្ឆេទ និង​ពេលវេលា
Comment[lt]=Įrankis sulieti nuotraukų pluoštą
Comment[lv]=Rīks atsevišķu attēlu sapludināšanai
Comment[nb]=Et verktøy for å flette sammen bilder med eksponeringsområde
Comment[nl]=Een hulpmiddel voor het mengen van afbeeldingen tussen haakjes
Comment[pl]=Narzędzie do przenikania serii obrazów o różnym naświetleniu
Comment[pt]=Uma ferramenta para mostrar imagens delimitadas
Comment[pt_BR]=Uma ferramenta para mostrar imagens delimitadas
Comment[ro]=O unealtă pentru fuzionarea imaginilor făcute cu expuneri diferite
Comment[ru]=Инструмент для брекетинга снимков
Comment[sk]=Nástroj na splynutie zubatých obrázkov
Comment[sl]=Orodje za zlivanje slik posnetih z različnimi nastavitvami (bracketing)
Comment[sv]=Ett verktyg för att blanda avgränsade bilder
Comment[th]=เครื่องมือสำหรับผสานส่วนมุมของภาพต่าง ๆ 
Comment[tr]=Parantezli resimleri karıştırmak için bir araç
Comment[uk]=Інструмент для злиття зображень «вилки»
Comment[x-test]=xxA tool to blend bracketed imagesxx
Comment[zh_CN]=一个混合加括号图像的工具
Comment[zh_TW]=混合括弧內影像的工具
Icon=kipi-expoblending
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_expoblending
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-4.11.0.tar.bz2: digikam-4.11.0/extra/kipi-plugins/expoblending/plugin/kipiplugin_expoblending.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Expo Blending
Name=Expo Blending
Name[bg]=Сливане на експозиция
Name[bs]=ExpoBlending
Name[ca]=Fusió d'exposició
Name[ca@valencia]=Fusió d'exposició
Name[cs]=Smísení expozice
Name[da]=Ekspo.-blanding
Name[de]=Belichtungsvermischung
Name[el]=Ανάμειξη έκθεσης
Name[en_GB]=Expo Blending
Name[es]=Mezcla de la exposición
Name[et]=Pildiliitmine
Name[eu]=Esposizioaren nahasketa
Name[fr]=Fusion d'exposition
Name[gl]=Mistura da exposición
Name[is]=Lýsingarblöndun
Name[it]=Doppia esposizione
Name[km]=ការ​លាយ​កម្រិត​បង្ហាញ
Name[lv]=Expo Blending
Name[nb]=Ekspo-fletting
Name[nl]=Belichting mengen
Name[pl]=Przenikanie naświetleń
Name[pt]=Mistura da Exposição
Name[pt_BR]=Mistura da exposição
Name[ro]=Fuziune expunere
Name[ru]=Смешивание экспозиции
Name[sk]=Expo Blending
Name[sl]=Expo Blending
Name[sv]=Exponeringsblandning
Name[tr]=Expo Blending
Name[uk]=Злиття експозиції
Name[x-test]=xxExpo Blendingxx
Name[zh_CN]=曝光混合
Name[zh_TW]=曝光混合
Comment=A tool to blend bracketed images
Comment[bg]=Инструмент за сливане на снимани "в клин" снимки
Comment[bs]=Alat za miješanje kockastih slika
Comment[ca]=Una eina per fusionar imatges fetes amb bràqueting
Comment[ca@valencia]=Una eina per fusionar imatges fetes amb bràqueting
Comment[cs]=Nástroj pro mísení sekvence obrázků
Comment[da]=Et værktøj til at blande billeder med bracket
Comment[de]=Ein Werkzeug, um Bilder aus einer Belichtungsreihe zu mischen
Comment[el]=Εργαλείο ανάμειξης οριοθετημένων εικόνων
Comment[en_GB]=A tool to blend bracketed images
Comment[es]=Una herramienta para mostrar imágenes delimitadas
Comment[et]=Tööriist kahveldatud piltide liitmiseks
Comment[eu]=Urkilatutako irudiak nahasteko tresna
Comment[fr]=Outil pour fusionner des images prises avec différentes expositions
Comment[gl]=Unha ferramenta para mesturar as imaxes tomadas en "bracketing"
Comment[is]=Verkfæri til að setja saman mislýstar myndraðir (bracketed)
Comment[it]=Uno strumento per fondere immagini sovrapposte
Comment[km]=ឧបករណ៍​ត្រូវ​លៃតម្រូវ​កាលបរិច្ឆេទ និង​ពេលវេលា
Comment[lt]=Įrankis sulieti nuotraukų pluoštą
Comment[lv]=Rīks atsevišķu attēlu sapludināšanai
Comment[nb]=Et verktøy for å flette sammen bilder med eksponeringsområde
Comment[nl]=Een hulpmiddel voor het mengen van afbeeldingen tussen haakjes
Comment[pl]=Narzędzie do przenikania serii obrazów o różnym naświetleniu
Comment[pt]=Uma ferramenta para mostrar imagens delimitadas
Comment[pt_BR]=Ferramenta para misturar imagens delimitadas
Comment[ro]=O unealtă pentru fuzionarea imaginilor făcute cu expuneri diferite
Comment[ru]=Инструмент для брекетинга снимков
Comment[sk]=Nástroj na splynutie zubatých obrázkov
Comment[sl]=Orodje za zlivanje slik posnetih z različnimi nastavitvami (bracketing)
Comment[sv]=Ett verktyg för att blanda avgränsade bilder
Comment[th]=เครื่องมือสำหรับผสานส่วนมุมของภาพต่าง ๆ 
Comment[tr]=Parantezli resimleri karıştırmak için bir araç
Comment[uk]=Інструмент для злиття зображень «вилки»
Comment[x-test]=xxA tool to blend bracketed imagesxx
Comment[zh_CN]=一个混合加括号图像的工具
Comment[zh_TW]=混合括弧內影像的工具
Icon=kipi-expoblending
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_expoblending
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
